@@ -16,12 +16,6 @@
 
 package discover
 
-// Config represents the configuration options for discovery
-type Config struct {
-	Root                                    string
-	NVIDIAContainerToolkitCLIExecutablePath string
-}
-
 // Device represents a discovered character device.
 type Device struct {
 	HostPath string
@@ -32,6 +26,7 @@ type Device struct {
 type Mount struct {
 	HostPath string
 	Path     string
+	Options  []string
 }
 
 // Hook represents a discovered hook.
@@ -41,8 +36,9 @@ type Hook struct {
 	Args      []string
 }
 
-//go:generate moq -stub -out discover_mock.go . Discover
 // Discover defines an interface for discovering the devices, mounts, and hooks available on a system
+//
+//go:generate moq -stub -out discover_mock.go . Discover
 type Discover interface {
 	Devices() ([]Device, error)
 	Mounts() ([]Mount, error)
