@@ -16,33 +16,41 @@
 
 package info
 
-import "gitlab.com/nvidia/cloud-native/go-nvlib/pkg/nvinfo"
+import (
+	"github.com/NVIDIA/go-nvlib/pkg/nvlib/info"
 
-// Logger is a basic interface for logging to allow these functions to be called
-// from code where logrus is not used.
-type Logger interface {
-	Infof(string, ...interface{})
-	Debugf(string, ...interface{})
-}
+	"github.com/NVIDIA/nvidia-container-toolkit/internal/config/image"
+	"github.com/NVIDIA/nvidia-container-toolkit/internal/logger"
+)
 
 // ResolveAutoMode determines the correct mode for the platform if set to "auto"
-func ResolveAutoMode(logger Logger, mode string) (rmode string) {
+func ResolveAutoMode(logger logger.Interface, mode string, image image.CUDA) (rmode string) {
+	return resolveMode(logger, mode, image, nil)
+}
+
+func resolveMode(logger logger.Interface, mode string, image image.CUDA, propertyExtractor info.PropertyExtractor) (rmode string) {
 	if mode != "auto" {
+		logger.Infof("Using requested mode '%s'", mode)
 		return mode
 	}
 	defer func() {
 		logger.Infof("Auto-detected mode as '%v'", rmode)
 	}()
 
-	isTegra, reason := nvinfo.IsTegraSystem()
-	logger.Debugf("Is Tegra-based system? %v: %v", isTegra, reason)
-
-	hasNVML, reason := nvinfo.HasNVML()
-	logger.Debugf("Has NVML? %v: %v", hasNVML, reason)
-
-	if isTegra && !hasNVML {
-		return "csv"
+	if image.OnlyFullyQualifiedCDIDevices() {
+		return "cdi"
 	}
 
+	nvinfo := info.New(
+		info.WithLogger(logger),
+		info.WithPropertyExtractor(propertyExtractor),
+	)
+
+	switch nvinfo.ResolvePlatform() {
+	case info.PlatformNVML, info.PlatformWSL:
+		return "legacy"
+	case info.PlatformTegra:
+		return "csv"
+	}
 	return "legacy"
 }
