@@ -16,8 +16,6 @@
 
 package constraints
 
-import "fmt"
-
 const (
 	equal        = "="
 	notEqual     = "!="
@@ -37,15 +35,3 @@ func (c always) Assert() error {
 func (c always) String() string {
 	return "true"
 }
-
-// invalid is an invalid constraint and can never be met
-type invalid string
-
-func (c invalid) Assert() error {
-	return fmt.Errorf("invalid constraint: %v", c.String())
-}
-
-// String returns the string representation of the contraint
-func (c invalid) String() string {
-	return string(c)
-}
